@@ -1,4 +1,4 @@
-# Copyright 2016-2017 Red Hat, Inc.
+# Copyright 2016-2018 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,8 +23,9 @@ import logging
 
 import six
 
-from .netinfo import bonding, bridges, dns
+from .netinfo import bonding, bridges
 from vdsm.common.conv import tobool
+from vdsm.network import dns
 from vdsm.network.ip.address import prefix2netmask
 from vdsm.network.link import bond
 from vdsm.network.link import iface
